==> nocc-1.8.1.tbz: www/nocc/lang/ga.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: ga.php 1931 2009-07-05 11:07:47Z gerundt $
 */

/** Irish (Gaeilge)
 *
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author D.de.loinsigh
 */

$default_date_format = '%d-%m-%Y';
$no_locale_date_format = '%d-%m-%Y';
$default_time_format = '%I:%M %p';
$err_user_empty = 'Tá an réimse logála isteach folamh';
$err_passwd_empty = 'Tá an réimse fhocail faire folamh';
$alt_delete = 'Scrios teachtaireacht roghnaithe';
$alt_delete_one = 'Scrios an teachtaireacht';
$alt_new_msg = 'Teachtaireachtaí nua';
$alt_reply = 'Freagair an t-údar';
$alt_reply_all = 'Freagair uile';
$alt_forward = 'Seol ar aghaidh';
$alt_next = 'Ar aghaidh';
$alt_prev = 'Roimhe';
$title_next_page = 'An chéad leathanach eile';
$title_prev_page = 'Leathanach roimhe';
$title_next_msg = 'An chéad teachtaireacht eile';
$title_prev_msg = 'Teachtaireacht roimhe';
$html_on = 'ar';
$html_theme_label = 'Téama';
$html_welcome = 'Fáilte go %1$s';
$html_login = 'Logáil isteach';
$html_passwd = 'Focal faire';
$html_submit = 'Cuir isteach';
$html_help = 'Cuidiú';
$html_server = 'Freastalaí';
$html_wrong = 'Tá an logáil isteach nó an focal faire mícheart';
$html_retry = 'Atriail';
$html_remember = 'Cuimhnigh socraithe';
$html_msgperpage_label = 'Teachtaireachtaí sa leathanach';
$html_preferences = 'Sainroghanna';
$html_full_name_label = 'Ainm iomlán';
$html_email_address_label = 'Seoladh ríomhphoist';
$html_ccself = 'Cc féin';
$html_hide_addresses = 'Folaigh seoltaí';
$html_outlook_quoting = 'Sleachta de chineál Outlook';
$html_reply_to = 'Freagair chuig';
$html_use_signature = 'Úsáid síniú';
$html_signature = 'Síniú';
$html_reply_leadin_label = 'Freagair Leadin';
$html_prefs_updated = 'Sainroghanna uasdátaithe';
$html_manage_folders_link = 'Bainistigh comhaid IMAP';
$html_manage_filters_link = 'Bainistigh scagairí ríomhphoist';
$html_use_graphical_smilies = 'Úsáid straoiseoga grafacha';
$html_sent_folder_label = 'Cóipeáil teachtaireachtaí seolta go comhad tiomnaithe';
$html_trash_folder_label = 'Bog teachtaireachtaí scriosta chuig comhad tiomnaithe';
$html_colored_quotes = 'Sleachta dathaithe';
$html_display_struct = 'Taispeáin teasc struchtúrtha';
$html_send_html_mail = 'Seol teachtaireacht ríomhphoist i bhformáid HTML';
$html_folders = 'Comhaid';
$html_folders_create_failed = 'Níorbh fhéidir leis an chomhad a bheith cruthaithe!';
$html_folders_sub_failed = 'Níorbh fhéidir suibscríobh leis an chomhad!';
$html_folders_unsub_failed = 'Níorbh fhéidir díliostáil den chomhad!';
$html_folders_rename_failed = 'Níorbh fhéidir an comhad a bheith athainmnithe!';
$html_folders_updated = 'Comhaid uasdátaithe';
$html_folder_subscribe = 'Liostáil le';
$html_folder_rename = 'Athainmnigh';
$html_folder_create = 'Cruthaigh comhad nua dar teideal';
$html_folder_remove = 'Díliostáil de';
$html_folder_delete = 'Scrios';
$html_folder_to = 'chuig';
$html_filter_remove = 'Scrios';
$html_filter_body = 'Tathag na teachtaireachta';
$html_filter_subject = 'Ábhar na teachtaireachta';
$html_filter_to = 'Chuig réimse';
$html_filter_cc = 'Cc réimse';
$html_filter_from = 'Ón réimse';
$html_filter_change_tip = 'Chun scagaire a athrú, ní gá duit ach é a fhorscríobh.';
$html_reapply_filters = 'Athfheidhmigh scagairí uile';
$html_filter_contains = 'san áireamh';
$html_filter_name = 'Ainm scagaire';
$html_filter_action = 'Gníomh scagaire';
$html_filter_moveto = 'Bog chuig';
$html_select_one = '--Roghnaigh Ceann Amháin--';
$html_and = 'Agus';
$html_new_msg_in = 'Teachtaireachtaí nua i';
$html_or = 'nó';
$html_move = 'Bog';
$html_copy = 'Cóipeáil';
$html_messages_to = 'teachtaireachtaí roghnaithe chuig';
$html_gotopage = 'Téigh chuig Leathanach';
$html_gotofolder = 'Téigh chuig comhad';
$html_other_folders = 'Liosta comhad';
$html_page = 'Leathanach';
$html_of = 'de';
$html_view_header = 'Amharc ar cheanntásc';
$html_remove_header = 'Folaigh ceanntásc';
$html_inbox = 'Bosca isteach';
$html_new_msg = 'Scríobh';
$html_reply = 'Freagair';
$html_reply_short = 'Ml';
$html_reply_all = 'Freagair uile';
$html_forward = 'Seol ar aghaidh';
$html_forward_short = 'Seol ar aghaidh';
$html_forward_info = 'Seolfar an teachtaireacht curtha ar aghaidh mar iatán leis an cheann seo.';
$html_delete = 'Scios';
$html_new = 'Nua';
$html_mark = 'Scrios';
$html_att_label = 'Iatán';
$html_atts_label = 'Iatáin';
$html_att_unknown = '[neamhaithnid]';
$html_attach = 'Iaigh';
$html_attach_forget = 'Caithfidh tú do chomhad a cheangal sula seolann tú do theachtaireacht!';
$html_attach_delete = 'Bain a bhfuil roghnaithe';
$html_attach_none = 'Caithfidh tú comhad le ceangal a roghnú!';
$html_sort_by = 'Sórtáil de réir';
$html_sort = 'Sórtáil';
$html_from = 'Ó';
$html_subject = 'Ábhar';
$html_date = 'Dáta';
$html_sent = 'Seol';
$html_wrote = 'a scríobh';
$html_size = 'Méid';
$html_totalsize = 'Méid iomlán';
$html_kb = 'kB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'bearta';
$html_filename = 'Ainm an chomhaid';
$html_to = 'Chuig';
$html_cc = 'Cc';
$html_bcc_label = 'Bcc';
$html_nosubject = 'Ábhar ar bith';
$html_send = 'Seol';
$html_cancel = 'Ceallaigh';
$html_no_mail = 'Teachtaireacht ar bith.';
$html_logout = 'Logáil amach';
$html_msg = 'Teachtaireacht';
$html_msgs = 'Teachtaireachtaí';
$html_configuration = 'Chan fhuil an freastalaí seo cumraithe go maith !';
$html_priority_label = 'Tosaíocht';
$html_lowest = 'Is ísle';
$html_low = 'Íseal';
$html_normal = 'Normálta';
$html_high = 'Ard';
$html_highest = 'Is airde';
$html_receipt = 'Iarr admháil aischurtha';
$html_select = 'Roghnaigh';
$html_select_all = 'Inbhéartaigh roghnúchán';
$html_loading_image = 'Ag lódáil íomhá';
$html_send_confirmed = 'Glacadh le do phost le seachadadh';
$html_no_sendaction = 'Ní mionsonraíodh gníomh ar bith. Bain triail as JavaScript a chumasú.';
$html_error_occurred = 'Tharla earráid';
$html_prefs_file_error = 'Níorbh fhéidir comhad sainroghanna a oscailt le haghaidh scríofa.';
$html_wrap = 'Timfhill teachtaireachtaí amach ar:';
$html_wrap_none = 'Rud ar bith';
$html_usenet_separator = 'Deighilteoir Usenet ("-- \n") roimh shíniú';
$html_mark_as = 'Marcáil';
$html_read = 'léite';
$html_unread = 'neamhléite';
$html_encoding_label = 'Ionchódú carachtar';
$html_add = 'Cuir le';
$html_contacts = '%1$s teagmhálaí';
$html_modify = 'Modhnaigh';
$html_back = 'Ar ais';
$html_contact_add = 'Cuir teagmhálaí nua leis';
$html_contact_mod = 'Modhnaigh teagmhálaí';
$html_contact_first = 'Céadainm';
$html_contact_last = 'Sloinne';
$html_contact_nick = 'Goid';
$html_contact_mail = 'Ríomhphostanna';
$html_contact_list = 'Liosta teagmhálaithe de %1$s';
$html_contact_del = 'ón liosta teagmhálaithe';
$html_contact_count = '%1$d teagmhálaí';
$html_contact_err1 = 'Is é an líon is mó teagmhálaithe ar féidir a bheith agat ná';
$html_contact_err2 = 'Ní féidir leat teagmhálaí nua a chur leis';
$html_contact_err3 = 'Níl cead rochtana agat don liosta teagmhálaithe';
$html_contact_none = 'Níorbh fhéidir teagmhálaithe ar bith a aimsiú.';
$html_del_msg = 'Ar mhaith leat na teachtaireachtaí roghnaithe a scrios?';
$html_down_mail = 'Íoslódáil';
$original_msg = '-- Teachtaireacht bhunaidh --';
$to_empty = 'Ní mór don réimse dar teideal "Chuig" a bheith líonta!';
$html_images_warning = 'As ucht do slándála, ní thaispeántar cianphictiúir.';
$html_images_display = 'Pictiúir taispeána';
$html_smtp_error_no_conn = 'Níorbh fhéidir ceangal SMTP a oscailt';
$html_smtp_error_unexpected = 'Freagairt ionchais SMTP:';
$lang_could_not_connect = 'Níor fhéidir ceangal leis an fhreastalaí';
$lang_invalid_msg_num = 'Droch-uimhir teachtaireachta';
$html_file_upload_attack = 'Ionsaí féideartha ar uaslódáil comhaid';
$html_invalid_email_address = 'Seoladh neamhbhailí ríomhphoist';
$html_invalid_msg_per_page = 'Uimhir neamhbhailí teachtaireachtaí sa leathanach';
$html_invalid_wrap_msg = 'Leithead timfhillte teachtaireachta neamhbhailí';
$html_seperate_msg_win = 'Teachtaireachtaí i bhfuinneog ar leith';
$html_err_file_contacts = 'Níor fhéidir comhad teagmhálaithe a oscail le haghaidh scríofa.';
$html_session_file_error = 'Níorbh fhéidir comhad an tseisiúin a oscailt le haghaidh scríofa.';
$html_login_not_allowed = 'Ní cheadaítear an logáil isteach seo don cheangal.';
$lang_err_send_delay = 'Caithfidh tú fanacht idir dhá ríomhphost (%1$d soicind)';
$html_search = 'Cuardaigh';

==> nocc-1.8.3.tbz: www/nocc/lang/ga.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: ga.php 2164 2010-04-05 12:50:59Z gerundt $
 */

/** Irish (Gaeilge)
 *
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author D.de.loinsigh
 */

$default_date_format = '%d-%m-%Y';
$no_locale_date_format = '%d-%m-%Y';
$default_time_format = '%I:%M %p';
$err_user_empty = 'Tá an réimse logála isteach folamh';
$err_passwd_empty = 'Tá an réimse fhocail faire folamh';
$alt_delete = 'Scrios teachtaireacht roghnaithe';
$alt_delete_one = 'Scrios an teachtaireacht';
$alt_new_msg = 'Teachtaireachtaí nua';
$alt_reply = 'Freagair an t-údar';
$alt_reply_all = 'Freagair uile';
$alt_forward = 'Seol ar aghaidh';
$alt_next = 'Ar aghaidh';
$alt_prev = 'Roimhe';
$title_next_page = 'An chéad leathanach eile';
$title_prev_page = 'Leathanach roimhe';
$title_next_msg = 'An chéad teachtaireacht eile';
$title_prev_msg = 'Teachtaireacht roimhe';
$html_theme_label = 'Téama';
$html_welcome = 'Fáilte go %1$s';
$html_login = 'Logáil isteach';
$html_submit = 'Cuir isteach';
$html_help = 'Cuidiú';
$html_wrong = 'Tá an logáil isteach nó an focal faire mícheart';
$html_retry = 'Atriail';
$html_remember = 'Cuimhnigh socraithe';
$html_msgperpage_label = 'Teachtaireachtaí sa leathanach';
$html_preferences = 'Sainroghanna';
$html_full_name_label = 'Ainm iomlán';
$html_email_address_label = 'Seoladh ríomhphoist';
$html_ccself = 'Cc féin';
$html_hide_addresses = 'Folaigh seoltaí';
$html_outlook_quoting = 'Sleachta de chineál Outlook';
$html_reply_to = 'Freagair chuig';
$html_use_signature = 'Úsáid síniú';
$html_signature = 'Síniú';
$html_reply_leadin_label = 'Freagair Leadin';
$html_prefs_updated = 'Sainroghanna uasdátaithe';
$html_manage_folders_link = 'Bainistigh comhaid IMAP';
$html_manage_filters_link = 'Bainistigh scagairí ríomhphoist';
$html_use_graphical_smilies = 'Úsáid straoiseoga grafacha';
$html_sent_folder_label = 'Cóipeáil teachtaireachtaí seolta go comhad tiomnaithe';
$html_trash_folder_label = 'Bog teachtaireachtaí scriosta chuig comhad tiomnaithe';
$html_colored_quotes = 'Sleachta dathaithe';
$html_display_struct = 'Taispeáin teasc struchtúrtha';
$html_send_html_mail = 'Seol teachtaireacht ríomhphoist i bhformáid HTML';
$html_folders = 'Comhaid';
$html_folders_create_failed = 'Níorbh fhéidir leis an chomhad a bheith cruthaithe!';
$html_folders_sub_failed = 'Níorbh fhéidir suibscríobh leis an chomhad!';
$html_folders_unsub_failed = 'Níorbh fhéidir díliostáil den chomhad!';
$html_folders_rename_failed = 'Níorbh fhéidir an comhad a bheith athainmnithe!';
$html_folders_updated = 'Comhaid uasdátaithe';
$html_folder_subscribe = 'Liostáil le';
$html_folder_rename = 'Athainmnigh';
$html_folder_create = 'Cruthaigh comhad nua dar teideal';
$html_folder_remove = 'Díliostáil de';
$html_folder_delete = 'Scrios';
$html_folder_to = 'chuig';
$html_filter_remove = 'Scrios';
$html_filter_body = 'Tathag na teachtaireachta';
$html_filter_subject = 'Ábhar na teachtaireachta';
$html_filter_to = 'Chuig réimse';
$html_filter_cc = 'Cc réimse';
$html_filter_from = 'Ón réimse';
$html_filter_change_tip = 'Chun scagaire a athrú, ní gá duit ach é a fhorscríobh.';
$html_reapply_filters = 'Athfheidhmigh scagairí uile';
$html_filter_contains = 'san áireamh';
$html_filter_name = 'Ainm scagaire';
$html_filter_action = 'Gníomh scagaire';
$html_filter_moveto = 'Bog chuig';
$html_select_one = '--Roghnaigh Ceann Amháin--';
$html_and = 'Agus';
$html_new_msg_in = 'Teachtaireachtaí nua i';
$html_or = 'nó';
$html_move = 'Bog';
$html_copy = 'Cóipeáil';
$html_messages_to = 'teachtaireachtaí roghnaithe chuig';
$html_gotopage = 'Téigh chuig Leathanach';
$html_gotofolder = 'Téigh chuig comhad';
$html_other_folders = 'Liosta comhad';
$html_page = 'Leathanach';
$html_of = 'de';
$html_view_header = 'Amharc ar cheanntásc';
$html_remove_header = 'Folaigh ceanntásc';
$html_inbox = 'Bosca isteach';
$html_new_msg = 'Scríobh';
$html_reply = 'Freagair';
$html_reply_short = 'Ml';
$html_reply_all = 'Freagair uile';
$html_forward = 'Seol ar aghaidh';
$html_forward_short = 'Seol ar aghaidh';
$html_forward_info = 'Seolfar an teachtaireacht curtha ar aghaidh mar iatán leis an cheann seo.';
$html_delete = 'Scios';
$html_new = 'Nua';
$html_mark = 'Scrios';
$html_att_label = 'Iatán';
$html_unknown = '[neamhaithnid]';
$html_attach = 'Iaigh';
$html_attach_forget = 'Caithfidh tú do chomhad a cheangal sula seolann tú do theachtaireacht!';
$html_attach_delete = 'Bain a bhfuil roghnaithe';
$html_attach_none = 'Caithfidh tú comhad le ceangal a roghnú!';
$html_sort_by = 'Sórtáil de réir';
$html_sort = 'Sórtáil';
$html_from = 'Ó';
$html_subject = 'Ábhar';
$html_date = 'Dáta';
$html_sent_label = 'Seol';
$html_wrote = 'a scríobh';
$html_size = 'Méid';
$html_totalsize = 'Méid iomlán';
$html_kb = 'kB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'bearta';
$html_filename = 'Ainm an chomhaid';
$html_to = 'Chuig';
$html_cc = 'Cc';
$html_bcc_label = 'Bcc';
$html_nosubject = 'Ábhar ar bith';
$html_send = 'Seol';
$html_cancel = 'Ceallaigh';
$html_no_mail = 'Teachtaireacht ar bith.';
$html_logout = 'Logáil amach';
$html_msg = 'Teachtaireacht';
$html_msgs = 'Teachtaireachtaí';
$html_configuration = 'Chan fhuil an freastalaí seo cumraithe go maith !';
$html_priority_label = 'Tosaíocht';
$html_lowest = 'Is ísle';
$html_low = 'Íseal';
$html_normal = 'Normálta';
$html_high = 'Ard';
$html_highest = 'Is airde';
$html_receipt = 'Iarr admháil aischurtha';
$html_select = 'Roghnaigh';
$html_select_all = 'Inbhéartaigh roghnúchán';
$html_loading_image = 'Ag lódáil íomhá';
$html_send_confirmed = 'Glacadh le do phost le seachadadh';
$html_no_sendaction = 'Ní mionsonraíodh gníomh ar bith. Bain triail as JavaScript a chumasú.';
$html_error_occurred = 'Tharla earráid';
$html_prefs_file_error = 'Níorbh fhéidir comhad sainroghanna a oscailt le haghaidh scríofa.';
$html_wrap = 'Timfhill teachtaireachtaí amach ar:';
$html_wrap_none = 'Rud ar bith';
$html_usenet_separator = 'Deighilteoir Usenet ("-- \n") roimh shíniú';
$html_mark_as = 'Marcáil';
$html_read = 'léite';
$html_unread = 'neamhléite';
$html_encoding_label = 'Ionchódú carachtar';
$html_add = 'Cuir le';
$html_contacts = '%1$s teagmhálaí';
$html_modify = 'Modhnaigh';
$html_back = 'Ar ais';
$html_contact_add = 'Cuir teagmhálaí nua leis';
$html_contact_mod = 'Modhnaigh teagmhálaí';
$html_contact_first = 'Céadainm';
$html_contact_last = 'Sloinne';
$html_contact_nick = 'Goid';
$html_contact_mail = 'Ríomhphostanna';
$html_contact_list = 'Liosta teagmhálaithe de %1$s';
$html_contact_del = 'ón liosta teagmhálaithe';
$html_contact_count = '%1$d teagmhálaí';
$html_contact_err1 = 'Is é an líon is mó teagmhálaithe ar féidir a bheith agat ná';
$html_contact_err2 = 'Ní féidir leat teagmhálaí nua a chur leis';
$html_contact_err3 = 'Níl cead rochtana agat don liosta teagmhálaithe';
$html_contact_none = 'Níorbh fhéidir teagmhálaithe ar bith a aimsiú.';
$html_del_msg = 'Ar mhaith leat na teachtaireachtaí roghnaithe a scrios?';
$html_down_mail = 'Íoslódáil';
$original_msg = '-- Teachtaireacht bhunaidh --';
$to_empty = 'Ní mór don réimse dar teideal "Chuig" a bheith líonta!';
$html_images_warning = 'As ucht do slándála, ní thaispeántar cianphictiúir.';
$html_images_display = 'Pictiúir taispeána';
$html_smtp_error_no_conn = 'Níorbh fhéidir ceangal SMTP a oscailt';
$html_smtp_error_unexpected = 'Freagairt ionchais SMTP:';
$lang_could_not_connect = 'Níor fhéidir ceangal leis an fhreastalaí';
$lang_invalid_msg_num = 'Droch-uimhir teachtaireachta';
$html_file_upload_attack = 'Ionsaí féideartha ar uaslódáil comhaid';
$html_invalid_email_address = 'Seoladh neamhbhailí ríomhphoist';
$html_invalid_msg_per_page = 'Uimhir neamhbhailí teachtaireachtaí sa leathanach';
$html_invalid_wrap_msg = 'Leithead timfhillte teachtaireachta neamhbhailí';
$html_seperate_msg_win = 'Teachtaireachtaí i bhfuinneog ar leith';
$html_err_file_contacts = 'Níor fhéidir comhad teagmhálaithe a oscail le haghaidh scríofa.';
$html_session_file_error = 'Níorbh fhéidir comhad an tseisiúin a oscailt le haghaidh scríofa.';
$html_login_not_allowed = 'Ní cheadaítear an logáil isteach seo don cheangal.';
$lang_err_send_delay = 'Caithfidh tú fanacht idir dhá ríomhphost (%1$d seconds)';
$html_search = 'Cuardaigh';
